@@ -55,16 +55,18 @@ if pkgutil.find_loader("intervaltree"):
 else:
     logging.error("intervaltree is not available. This can lead some features of PM4Py to not work correctly!")
 
-__version__ = '2.0.1.2'
+VERSION = '2.1.0.1'
+
+__version__ = VERSION
 __doc__ = "Process Mining for Python (PM4Py)"
 __author__ = 'Fraunhofer Institute for Applied Technology'
 __author_email__ = 'pm4py@fit.fraunhofer.de'
 __maintainer__ = 'Fraunhofer Institute for Applied Technology'
 __maintainer_email__ = "pm4py@fit.fraunhofer.de"
 
-from pm4py.read import read_xes, read_csv, read_petri_net, read_process_tree, read_dfg, format_dataframe, \
-    convert_to_event_log, convert_to_event_stream, convert_to_dataframe
-from pm4py.write import write_xes, write_csv, write_petri_net, write_process_tree, write_dfg
+from pm4py.read import read_xes, read_csv, read_petri_net, read_process_tree, read_dfg, \
+    convert_to_event_log, convert_to_event_stream, convert_to_dataframe, read_bpmn
+from pm4py.write import write_xes, write_csv, write_petri_net, write_process_tree, write_dfg, write_bpmn
 from pm4py.discovery import discover_petri_net_alpha, discover_petri_net_alpha_plus, discover_petri_net_heuristics, \
     discover_petri_net_inductive, discover_tree_inductive, discover_heuristics_net, discover_dfg
 from pm4py.conformance import conformance_tbr, conformance_alignments, evaluate_fitness_tbr, \
@@ -77,6 +79,7 @@ from pm4py.filtering import filter_start_activities, filter_end_activities, filt
     filter_variants_percentage, filter_paths, filter_timestamp, filter_trace_attribute
 from pm4py.stats import get_start_activities, get_end_activities, get_attributes, get_attribute_values, get_variants, \
     get_trace_attributes
+from pm4py.utils import format_dataframe
 
 # this package is available only for Python >= 3.5
 if sys.version_info >= (3, 5):
