@@ -1,13 +1,13 @@
-import pandas
+import pkgutil
+from enum import Enum
 
 from pm4py import util as pmutil
-from pm4py.algo.discovery.parameters import Parameters
 from pm4py.algo.discovery.alpha import variants
 from pm4py.algo.discovery.dfg.adapters.pandas import df_statistics
+from pm4py.algo.discovery.parameters import Parameters
 from pm4py.objects.conversion.log import converter as log_conversion
-from pm4py.util import xes_constants as xes_util
 from pm4py.util import exec_utils
-from enum import Enum
+from pm4py.util import xes_constants as xes_util
 
 
 class Variants(Enum):
@@ -50,14 +50,19 @@ def apply(log, parameters=None, variant=DEFAULT_VARIANT):
         parameters = {}
     case_id_glue = exec_utils.get_param_value(Parameters.CASE_ID_KEY, parameters, pmutil.constants.CASE_CONCEPT_NAME)
     activity_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters, xes_util.DEFAULT_NAME_KEY)
+    start_timestamp_key = exec_utils.get_param_value(Parameters.START_TIMESTAMP_KEY, parameters,
+                                                     None)
     timestamp_key = exec_utils.get_param_value(Parameters.TIMESTAMP_KEY, parameters, xes_util.DEFAULT_TIMESTAMP_KEY)
 
-    if isinstance(log, pandas.core.frame.DataFrame) and variant == ALPHA_VERSION_CLASSIC:
-        dfg = df_statistics.get_dfg_graph(log, case_id_glue=case_id_glue,
-                                          activity_key=activity_key,
-                                          timestamp_key=timestamp_key)
-        return exec_utils.get_variant(variant).apply_dfg(dfg, parameters=parameters)
-    return exec_utils.get_variant(variant).apply(log_conversion.apply(log, parameters, log_conversion.TO_EVENT_LOG), parameters)
+    if pkgutil.find_loader("pandas"):
+        import pandas
+        if isinstance(log, pandas.core.frame.DataFrame) and variant == ALPHA_VERSION_CLASSIC:
+            dfg = df_statistics.get_dfg_graph(log, case_id_glue=case_id_glue,
+                                              activity_key=activity_key,
+                                              timestamp_key=timestamp_key, start_timestamp_key=start_timestamp_key)
+            return exec_utils.get_variant(variant).apply_dfg(dfg, parameters=parameters)
+    return exec_utils.get_variant(variant).apply(log_conversion.apply(log, parameters, log_conversion.TO_EVENT_LOG),
+                                                 parameters)
 
 
 def apply_dfg(dfg, parameters=None, variant=ALPHA_VERSION_CLASSIC):
