@@ -2,9 +2,12 @@ from enum import Enum
 
 
 class Outputs(Enum):
+    DFG = "dfg"
     SEQUENCE = "sequence"
     PARALLEL = "parallel"
     START_ACTIVITIES = "start_activities"
     END_ACTIVITIES = "end_activities"
     ACTIVITIES = "activities"
     SKIPPABLE = "skippable"
+    ACTIVITIES_ALWAYS_HAPPENING = "activities_always_happening"
+    MIN_TRACE_LENGTH = "min_trace_length"
