@@ -1,8 +1,14 @@
 from pm4py.algo.filtering.common.timestamp.timestamp_common import get_dt_from_string
-from pm4py.objects.conversion.log import factory as log_converter
+from pm4py.objects.conversion.log import converter as log_converter
 from pm4py.objects.log.log import EventLog, EventStream
 from pm4py.util.xes_constants import DEFAULT_TIMESTAMP_KEY
 from pm4py.util.constants import PARAMETER_CONSTANT_TIMESTAMP_KEY
+from enum import Enum
+from pm4py.util import exec_utils
+
+
+class Parameters(Enum):
+    TIMESTAMP_KEY = PARAMETER_CONSTANT_TIMESTAMP_KEY
 
 
 def is_contained(trace, dt1, dt2, timestamp_key):
@@ -45,7 +51,7 @@ def filter_traces_contained(log, dt1, dt2, parameters=None):
         Upper bound to the interval
     parameters
         Possible parameters of the algorithm, including:
-            timestamp_key -> Attribute to use as timestamp
+            Parameters.TIMESTAMP_KEY -> Attribute to use as timestamp
 
     Returns
     ------------
@@ -54,8 +60,7 @@ def filter_traces_contained(log, dt1, dt2, parameters=None):
     """
     if parameters is None:
         parameters = {}
-    timestamp_key = parameters[
-        PARAMETER_CONSTANT_TIMESTAMP_KEY] if PARAMETER_CONSTANT_TIMESTAMP_KEY in parameters else DEFAULT_TIMESTAMP_KEY
+    timestamp_key = exec_utils.get_param_value(Parameters.TIMESTAMP_KEY, parameters, DEFAULT_TIMESTAMP_KEY)
     dt1 = get_dt_from_string(dt1)
     dt2 = get_dt_from_string(dt2)
     filtered_log = EventLog([trace for trace in log if is_contained(trace, dt1, dt2, timestamp_key)])
@@ -107,7 +112,7 @@ def filter_traces_intersecting(log, dt1, dt2, parameters=None):
         Upper bound to the interval
     parameters
         Possible parameters of the algorithm, including:
-            timestamp_key -> Attribute to use as timestamp
+            Parameters.TIMESTAMP_KEY -> Attribute to use as timestamp
 
     Returns
     ------------
@@ -138,7 +143,7 @@ def apply_events(log, dt1, dt2, parameters=None):
         Upper bound to the interval
     parameters
         Possible parameters of the algorithm, including:
-            timestamp_key -> Attribute to use as timestamp
+            Parameters.TIMESTAMP_KEY -> Attribute to use as timestamp
 
     Returns
     ------------
@@ -147,8 +152,7 @@ def apply_events(log, dt1, dt2, parameters=None):
     """
     if parameters is None:
         parameters = {}
-    timestamp_key = parameters[
-        PARAMETER_CONSTANT_TIMESTAMP_KEY] if PARAMETER_CONSTANT_TIMESTAMP_KEY in parameters else DEFAULT_TIMESTAMP_KEY
+    timestamp_key = exec_utils.get_param_value(Parameters.TIMESTAMP_KEY, parameters, DEFAULT_TIMESTAMP_KEY)
     dt1 = get_dt_from_string(dt1)
     dt2 = get_dt_from_string(dt2)
 
