@@ -1,8 +1,5 @@
 import json, pkgutil, logging
 
-import numpy as np
-import pandas as pd
-
 from pm4py.util.points_subset import pick_chosen_points_list
 from pm4py.statistics.attributes.parameters import Parameters
 from pm4py.util import exec_utils
@@ -81,8 +78,10 @@ def get_kde_numeric_attribute(values, parameters=None):
     y
         Y-axis values to represent
     """
-    if pkgutil.find_loader("scipy"):
+    if pkgutil.find_loader("scipy") and pkgutil.find_loader("numpy") and pkgutil.find_loader("pandas"):
         from scipy.stats import gaussian_kde
+        import numpy as np
+        import pandas as pd
 
         if parameters is None:
             parameters = {}
@@ -149,8 +148,10 @@ def get_kde_date_attribute(values, parameters=None):
     y
         Y-axis values to represent
     """
-    if pkgutil.find_loader("scipy"):
+    if pkgutil.find_loader("scipy") and pkgutil.find_loader("numpy") and pkgutil.find_loader("pandas"):
         from scipy.stats import gaussian_kde
+        import numpy as np
+        import pandas as pd
 
         if parameters is None:
             parameters = {}
