@@ -2,17 +2,19 @@ import tempfile
 from copy import copy
 
 from graphviz import Digraph
+from pm4py.util import exec_utils
+from pm4py.visualization.transition_system.parameters import Parameters
 
 
 def visualize(ts, parameters=None):
     if parameters is None:
         parameters = {}
 
-    image_format = parameters["format"] if "format" in parameters else "png"
-    show_labels = parameters["show_labels"] if "show_labels" in parameters else True
-    show_names = parameters["show_names"] if "show_names" in parameters else True
-    force_names = parameters["force_names"] if "force_names" in parameters else None
-    fillcolors = parameters["fillcolors"] if "fillcolors" in parameters else {}
+    image_format = exec_utils.get_param_value(Parameters.FORMAT, parameters, "png")
+    show_labels = exec_utils.get_param_value(Parameters.SHOW_LABELS, parameters, True)
+    show_names = exec_utils.get_param_value(Parameters.SHOW_NAMES, parameters, True)
+    force_names = exec_utils.get_param_value(Parameters.FORCE_NAMES, parameters, None)
+    fillcolors = exec_utils.get_param_value(Parameters.FILLCOLORS, parameters, {})
 
     for state in ts.states:
         state.label = state.name
@@ -23,12 +25,12 @@ def visualize(ts, parameters=None):
         nts = copy(ts)
         for index, state in enumerate(nts.states):
             state.name = state.name + " (%.2f)" % (force_names[state])
-            state.label = "%.2f" % (force_names[state]*100.0)
+            state.label = "%.2f" % (force_names[state] * 100.0)
             state.label = state.label + perc_char
         ts = nts
 
     filename = tempfile.NamedTemporaryFile(suffix='.gv')
-    viz = Digraph(ts.name, filename=filename.name, engine='dot', graph_attr={'bgcolor':'transparent'})
+    viz = Digraph(ts.name, filename=filename.name, engine='dot', graph_attr={'bgcolor': 'transparent'})
 
     # states
     viz.attr('node')
